%bcond_without  bundled_nasm
%define nasm_ver  2.14.02

# rhel7 still not has this…
%global _vpath_srcdir   .
%global _vpath_builddir %{_target_platform}

Name:           dav1d
Version:        0.5.2
Release:        2%{?dist}
Summary:        AV1 cross-platform Decoder

License:        BSD
URL:            https://code.videolan.org/videolan/dav1d
Source0:        %url/-/archive/%{version}/%{name}-%{version}.tar.bz2
%if %{with bundled_nasm}
Source1:        https://www.nasm.us/pub/nasm/releasebuilds/%{nasm_ver}/nasm-%{nasm_ver}.tar.xz
%endif

BuildRequires:  gcc
BuildRequires:  doxygen
BuildRequires:  meson >= 0.47.0
%if %{with bundled_nasm}
BuildRequires:  autoconf
%else
BuildRequires:  nasm >= 2.13.02
%endif

# EPEL7 GCC 8
BuildRequires:  devtoolset-8-toolchain
BuildRequires:  scl-utils

%description
dav1d is a new AV1 cross-platform Decoder, open-source, and focused on speed
and correctness.

%package -n libdav1d
Summary:        Library files for dav1d

%description -n libdav1d
Library files for dav1d, the AV1 cross-platform Decoder.

%package -n libdav1d-devel
Summary:        Development files for dav1d
Requires:       libdav1d%{?_isa} = %{version}-%{release}

%description -n libdav1d-devel
Development files for dav1d, the AV1 cross-platform Decoder.

%prep
%autosetup -p1 -n %{name}-%{version}
%setup -q %{?with_bundled_nasm:-a 1}

%build
do_build () {
%if %{with bundled_nasm}
mkdir bundled

pushd nasm-%{nasm_ver}
autoreconf
%configure
make all %{?_smp_mflags}
make install DESTDIR=$PWD/../bundled/
popd

export PATH=$PWD/bundled/%{_bindir}:$PATH
%endif

%meson --buildtype=release

%meson_build
%meson_build doc/html
}
export -f do_build
scl enable devtoolset-8 do_build

%install
%meson_install

%check
%meson_test

%files
%license COPYING doc/PATENTS
%doc CONTRIBUTING.md NEWS README.md
%{_bindir}/dav1d

%files -n libdav1d
%license COPYING doc/PATENTS
%{_libdir}/libdav1d.so.3*

%files -n libdav1d-devel
%doc %{_host_alias}/doc/html
%{_includedir}/%{name}
%{_libdir}/libdav1d.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Feb 15 2020 Dmitry Butskoy <Dmitry@Butskoy.name> - 0.5.2-2
- Rebuilt with bundled nasm >= 2.13.02 for epel7

* Thu Dec 05 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.5.2-1
- Release 0.5.2 (#1779827)

* Tue Nov 19 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.5.1-1
- Release 0.5.1 (#1765775, #1771993)

* Fri Oct 11 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.5.0-1
- Release 0.5.0 (#1760765)

* Fri Aug 09 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.4.0-1
- Release 0.4.0 (#1708919)

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Apr 29 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.3.0-1
- Release 0.3.0 (#1701494)

* Sun Apr 21 2019 Robert-André Mauchin <zebob.m@gmail.com> - 0.2.2-1
- Release 0.2.2 (#1701494)

* Tue Apr 16 2019 Adam Williamson <awilliam@redhat.com> - 0.2.1-3
- Rebuild with Meson fix for #1699099

* Tue Mar 26 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.2.1-2
- Rebuild with -Db_ndebug=true

* Tue Mar 12 2019 Robert-André Mauchin - 0.2.1-1
- Release 0.2.1

* Tue Mar 05 2019 Robert-André Mauchin - 0.2.0-1
- Release 0.2.0

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Dec 11 2018 Robert-André Mauchin <zebob.m@gmail.com> - 0.1.0-1
- Initial build
